@@ -1,10 +1,7 @@
 // Copyright (c) 1981-86 Robert A. Koeneke
 // Copyright (c) 1987-94 James E. Wilson
 //
-// This work is free software released under the GNU General Public License
-// version 2.0, and comes with ABSOLUTELY NO WARRANTY.
-//
-// See LICENSE and AUTHORS for more information.
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 // LOS (line-of-sight) and Looking functions
 
@@ -495,10 +492,7 @@ static bool lookSee(Coord_t coord, bool &transparent) {
         return false; // Don't look at a direct line of sight. A hack.
     }
 
-    // This was uninitialized but the `query == ESCAPE` below was causing
-    // a warning. Perhaps we can set it to `ESCAPE` here as default. -MRC-
-    char query = ESCAPE;
-
+    char key = ESCAPE;
     obj_desc_t msg = {'\0'};
 
     if (los_rocks_and_objects == 0 && tile.creature_id > 1 && monsters[tile.creature_id].lit) {
@@ -508,11 +502,11 @@ static bool lookSee(Coord_t coord, bool &transparent) {
         putStringClearToEOL(msg, Coord_t{0, 0});
 
         panelMoveCursor(coord);
-        query = getKeyInput();
+        key = getKeyInput();
 
-        if (query == 'r' || query == 'R') {
+        if (key == 'r' || key == 'R') {
             terminalSaveScreen();
-            query = (char) memoryRecall(j);
+            key = (char) memoryRecall(j);
             terminalRestoreScreen();
         }
     }
@@ -534,7 +528,7 @@ static bool lookSee(Coord_t coord, bool &transparent) {
                 putStringClearToEOL(msg, Coord_t{0, 0});
 
                 panelMoveCursor(coord);
-                query = getKeyInput();
+                key = getKeyInput();
             }
         }
 
@@ -565,14 +559,14 @@ static bool lookSee(Coord_t coord, bool &transparent) {
                 (void) sprintf(msg, "%s %s ---pause---", description, wall_description);
                 putStringClearToEOL(msg, Coord_t{0, 0});
                 panelMoveCursor(coord);
-                query = getKeyInput();
+                key = getKeyInput();
             }
         }
     }
 
     if (msg[0] != 0) {
         los_num_places_seen++;
-        if (query == ESCAPE) {
+        if (key == ESCAPE) {
             return true;
         }
     }
