@@ -1,10 +1,7 @@
 // Copyright (c) 1981-86 Robert A. Koeneke
 // Copyright (c) 1987-94 James E. Wilson
 //
-// This work is free software released under the GNU General Public License
-// version 2.0, and comes with ABSOLUTELY NO WARRANTY.
-//
-// See LICENSE and AUTHORS for more information.
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 // Game initialization and maintenance related functions
 
@@ -277,14 +274,12 @@ bool getDirectionWithMemory(char *prompt, int &direction) {
 
     while (true) {
         // Don't end a counted command. -CJS-
-        int save = game.command_count;
-
+        int oldCount = game.command_count;
         if (!getCommand(prompt, command)) {
             game.player_free_turn = true;
             return false;
         }
-
-        game.command_count = save;
+        game.command_count = oldCount;
 
         if (config::options::use_roguelike_keys) {
             command = mapRoguelikeKeysToKeypad(command);
