@@ -1,10 +1,7 @@
 // Copyright (c) 1981-86 Robert A. Koeneke
 // Copyright (c) 1987-94 James E. Wilson
 //
-// This work is free software released under the GNU General Public License
-// version 2.0, and comes with ABSOLUTELY NO WARRANTY.
-//
-// See LICENSE and AUTHORS for more information.
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 // Code executed when player dies
 
@@ -85,7 +82,7 @@ retry:
                 printMessage(CNIL);
                 printMessage("You are carrying:");
                 clearToBottom(1);
-                (void) displayInventory(0, py.pack.unique_items - 1, true, 0, CNIL);
+                (void) displayInventoryItems(0, py.pack.unique_items - 1, true, 0, CNIL);
                 printMessage(CNIL);
             }
         }
