@@ -1,10 +1,7 @@
 // Copyright (c) 1981-86 Robert A. Koeneke
 // Copyright (c) 1987-94 James E. Wilson
 //
-// This work is free software released under the GNU General Public License
-// version 2.0, and comes with ABSOLUTELY NO WARRANTY.
-//
-// See LICENSE and AUTHORS for more information.
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 // Misc code to access files used by Moria
 
@@ -53,7 +50,6 @@ void displayTextHelpFile(const std::string &filename) {
 
     constexpr uint8_t max_line_length = 80;
     char line_buffer[max_line_length];
-    char input;
 
     while (feof(file) == 0) {
         clearScreen();
@@ -65,8 +61,7 @@ void displayTextHelpFile(const std::string &filename) {
         }
 
         putStringClearToEOL("[ press any key to continue ]", Coord_t{23, 23});
-        input = getKeyInput();
-        if (input == ESCAPE) {
+        if (getKeyInput() == ESCAPE) {
             break;
         }
     }
@@ -173,7 +168,7 @@ void outputRandomLevelObjectsToFile() {
         Inventory_t &item = game.treasure.list[treasure_id];
         itemIdentifyAsStoreBought(item);
 
-        if ((item.flags & config::treasure::flags::TR_CURSED) != 0u) {
+        if (inventoryItemIsCursed(item)) {
             itemAppendToInscription(item, config::identification::ID_DAMD);
         }
 
