@@ -1,10 +1,7 @@
 // Copyright (c) 1981-86 Robert A. Koeneke
 // Copyright (c) 1987-94 James E. Wilson
 //
-// This work is free software released under the GNU General Public License
-// version 2.0, and comes with ABSOLUTELY NO WARRANTY.
-//
-// See LICENSE and AUTHORS for more information.
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 // Run the game: the main loop
 
@@ -2054,7 +2051,7 @@ static void playerRegenerateMana(int percent) {
 // Is an item an enchanted weapon or armor and we don't know? -CJS-
 // only returns true if it is a good enchantment
 static bool itemEnchanted(Inventory_t const &item) {
-    if (item.category_id < TV_MIN_ENCHANT || item.category_id > TV_MAX_ENCHANT || (item.flags & config::treasure::flags::TR_CURSED) != 0u) {
+    if (item.category_id < TV_MIN_ENCHANT || item.category_id > TV_MAX_ENCHANT || inventoryItemIsCursed(item)) {
         return false;
     }
 
