@@ -1,10 +1,7 @@
 // Copyright (c) 1981-86 Robert A. Koeneke
 // Copyright (c) 1987-94 James E. Wilson
 //
-// This work is free software released under the GNU General Public License
-// version 2.0, and comes with ABSOLUTELY NO WARRANTY.
-//
-// See LICENSE and AUTHORS for more information.
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 // Handle object identification and descriptions
 // ...mostly string handling code
@@ -219,14 +216,14 @@ static const char *objectDescription(char command) {
 }
 
 void identifyGameObject() {
-    char command;
-    if (!getCommand("Enter character to be identified :", command)) {
+    char itemId; // being an ASCII character representing the item/monster tile, e.g. `+` = Door.
+
+    if (!getTileCharacter("Enter character to be identified :", itemId)) {
         return;
     }
 
-    putStringClearToEOL(objectDescription(command), Coord_t{0, 0});
-
-    recallMonsterAttributes(command);
+    putStringClearToEOL(objectDescription(itemId), Coord_t{0, 0});
+    recallMonsterAttributes(itemId);
 }
 
 // Initialize all Potions, wands, staves, scrolls, etc.
@@ -441,7 +438,7 @@ void itemSetAsTried(Inventory_t const &item) {
 // Somethings been identified.
 // Extra complexity by CJS so that it can merge store/dungeon objects when appropriate.
 void itemIdentify(Inventory_t &item, int &item_id) {
-    if ((item.flags & config::treasure::flags::TR_CURSED) != 0u) {
+    if (inventoryItemIsCursed(item)) {
         itemAppendToInscription(item, config::identification::ID_DAMD);
     }
 
