@@ -1,10 +1,7 @@
 // Copyright (c) 1981-86 Robert A. Koeneke
 // Copyright (c) 1987-94 James E. Wilson
 //
-// This work is free software released under the GNU General Public License
-// version 2.0, and comes with ABSOLUTELY NO WARRANTY.
-//
-// See LICENSE and AUTHORS for more information.
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 // Inventory and inventory items
 
@@ -370,6 +367,14 @@ bool inventoryItemStackable(Inventory_t const &item) {
     return item.sub_category_id >= ITEM_SINGLE_STACK_MIN;
 }
 
+bool inventoryItemIsCursed(const Inventory_t &item) {
+    return (item.flags & config::treasure::flags::TR_CURSED) != 0u;
+}
+
+void inventoryItemRemoveCurse(Inventory_t &item) {
+    item.flags &= ~config::treasure::flags::TR_CURSED;
+}
+
 // AC gets worse -RAK-
 // Note: This routine affects magical AC bonuses so
 // that stores can detect the damage.
