@@ -1,10 +1,7 @@
 // Copyright (c) 1981-86 Robert A. Koeneke
 // Copyright (c) 1987-94 James E. Wilson
 //
-// This work is free software released under the GNU General Public License
-// version 2.0, and comes with ABSOLUTELY NO WARRANTY.
-//
-// See LICENSE and AUTHORS for more information.
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 // Code for mage spells
 
@@ -125,7 +122,7 @@ static void castSpell(int spell_id) {
             break;
         case MageSpellId::RemoveCurse:
             for (int id = 22; id < PLAYER_INVENTORY_SIZE; id++) {
-                py.inventory[id].flags = (uint32_t)(py.inventory[id].flags & ~config::treasure::flags::TR_CURSED);
+                inventoryItemRemoveCurse(py.inventory[id]);
             }
             break;
         case MageSpellId::FrostBolt:
