@@ -1,10 +1,7 @@
 // Copyright (c) 1981-86 Robert A. Koeneke
 // Copyright (c) 1987-94 James E. Wilson
 //
-// This work is free software released under the GNU General Public License
-// version 2.0, and comes with ABSOLUTELY NO WARRANTY.
-//
-// See LICENSE and AUTHORS for more information.
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 // Player specific variable definitions
 
@@ -449,7 +446,7 @@ static void playerRecalculateBonusesFromInventory() {
 
                 py.misc.display_to_ac += item.to_ac;
                 py.misc.display_ac += item.ac;
-            } else if ((item.flags & config::treasure::flags::TR_CURSED) == 0u) {
+            } else if (!inventoryItemIsCursed(item)) {
                 // Base AC values should always be visible,
                 // as long as the item is not cursed.
                 py.misc.display_ac += item.ac;
@@ -780,6 +777,29 @@ void playerStrength() {
     py.flags.status &= ~config::player::status::PY_STR_WGT;
 }
 
+bool playerLeftHandRingEmpty() {
+    return py.inventory[PlayerEquipment::Left].category_id == TV_NOTHING;
+}
+
+bool playerRightHandRingEmpty() {
+    return py.inventory[PlayerEquipment::Right].category_id == TV_NOTHING;
+}
+
+bool playerIsWieldingItem() {
+    if (py.inventory[PlayerEquipment::Wield].category_id == TV_NOTHING && py.inventory[PlayerEquipment::Auxiliary].category_id == TV_NOTHING) {
+        return false;
+    }
+    return true;
+}
+
+bool playerWornItemIsCursed(PlayerEquipment id) {
+    return inventoryItemIsCursed(py.inventory[id]);
+}
+
+void playerWornItemRemoveCurse(PlayerEquipment id) {
+    inventoryItemRemoveCurse(py.inventory[id]);
+}
+
 static bool playerCanRead() {
     if (py.flags.blind > 0) {
         printMessage("You can't see to read your spell book!");
@@ -899,7 +919,7 @@ void playerGainSpells() {
         displaySpellsList(spell_bank, spell_id, false, -1);
 
         char query;
-        while ((new_spells != 0) && getCommand("Learn which spell?", query)) {
+        while ((new_spells != 0) && getMenuItemId("Learn which spell?", query)) {
             int c = query - 'a';
 
             // test j < 23 in case i is greater than 22, only 22 spells
@@ -1290,7 +1310,7 @@ static void openClosedChest(Coord_t coord) {
         // Chest treasure is allocated as if a creature had been killed.
         // clear the cursed chest/monster win flag, so that people
         // can not win by opening a cursed chest
-        game.treasure.list[tile.treasure_id].flags &= ~config::treasure::flags::TR_CURSED;
+        inventoryItemRemoveCurse(game.treasure.list[tile.treasure_id]);
 
         (void) monsterDeath(coord, game.treasure.list[tile.treasure_id].flags);
 
