@@ -1,10 +1,7 @@
 // Copyright (c) 1981-86 Robert A. Koeneke
 // Copyright (c) 1987-94 James E. Wilson
 //
-// This work is free software released under the GNU General Public License
-// version 2.0, and comes with ABSOLUTELY NO WARRANTY.
-//
-// See LICENSE and AUTHORS for more information.
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 // Code for priest spells
 
@@ -132,7 +129,7 @@ static void playerRecitePrayer(int prayer_type) {
             for (auto &entry : py.inventory) {
                 // only clear flag for items that are wielded or worn
                 if (entry.category_id >= TV_MIN_WEAR && entry.category_id <= TV_MAX_WEAR) {
-                    entry.flags &= ~config::treasure::flags::TR_CURSED;
+                    inventoryItemRemoveCurse(entry);
                 }
             }
             break;
