@@ -1,10 +1,7 @@
 // Copyright (c) 1981-86 Robert A. Koeneke
 // Copyright (c) 1987-94 James E. Wilson
 //
-// This work is free software released under the GNU General Public License
-// version 2.0, and comes with ABSOLUTELY NO WARRANTY.
-//
-// See LICENSE and AUTHORS for more information.
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 // Monster memory info -CJS-
 
@@ -678,15 +675,12 @@ int memoryRecall(int monster_id) {
 // Allow access to monster memory. -CJS-
 void recallMonsterAttributes(char command) {
     int n = 0;
-    char query;
 
     for (int i = MON_MAX_CREATURES - 1; i >= 0; i--) {
         if (creatures_list[i].sprite == command && memoryMonsterKnown(creature_recall[i])) {
             if (n == 0) {
-                putString("You recall those details? [y/n]", Coord_t{0, 40});
-                query = getKeyInput();
-
-                if (query != 'y' && query != 'Y') {
+                int confirmed = getInputConfirmationWithAbort(40, "You recall those details?");
+                if (confirmed != 1) {
                     break;
                 }
 
@@ -695,7 +689,7 @@ void recallMonsterAttributes(char command) {
             }
             n++;
 
-            query = (char) memoryRecall(i);
+            int query = (char) memoryRecall(i);
             terminalRestoreScreen();
             if (query == ESCAPE) {
                 break;
