@@ -1,10 +1,7 @@
 // Copyright (c) 1981-86 Robert A. Koeneke
 // Copyright (c) 1987-94 James E. Wilson
 //
-// This work is free software released under the GNU General Public License
-// version 2.0, and comes with ABSOLUTELY NO WARRANTY.
-//
-// See LICENSE and AUTHORS for more information.
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 // Handle reading, writing, and displaying of high scores.
 
@@ -201,7 +198,6 @@ void showScoresScreen() {
     HighScore_t score{};
     readHighScore(score);
 
-    char input;
     char msg[100];
 
     int i = 0;
@@ -231,8 +227,7 @@ void showScoresScreen() {
         putStringClearToEOL("Rank  Points Name              Sex Race       Class  Lvl Killed By", Coord_t{0, 0});
         eraseLine(Coord_t{1, 0});
         putStringClearToEOL("[ press any key to continue ]", Coord_t{23, 23});
-        input = getKeyInput();
-        if (input == ESCAPE) {
+        if (getKeyInput() == ESCAPE) {
             break;
         }
     }
