@@ -1,10 +1,7 @@
 // Copyright (c) 1981-86 Robert A. Koeneke
 // Copyright (c) 1987-94 James E. Wilson
 //
-// This work is free software released under the GNU General Public License
-// version 2.0, and comes with ABSOLUTELY NO WARRANTY.
-//
-// See LICENSE and AUTHORS for more information.
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "headers.h"
 
@@ -75,17 +72,17 @@ static int inventoryItemIdOfCursedEquipment() {
         item_id = items[randomNumber(item_count) - 1];
     }
 
-    if ((py.inventory[PlayerEquipment::Body].flags & config::treasure::flags::TR_CURSED) != 0u) {
+    if (playerWornItemIsCursed(PlayerEquipment::Body)) {
         item_id = PlayerEquipment::Body;
-    } else if ((py.inventory[PlayerEquipment::Arm].flags & config::treasure::flags::TR_CURSED) != 0u) {
+    } else if (playerWornItemIsCursed(PlayerEquipment::Arm)) {
         item_id = PlayerEquipment::Arm;
-    } else if ((py.inventory[PlayerEquipment::Outer].flags & config::treasure::flags::TR_CURSED) != 0u) {
+    } else if (playerWornItemIsCursed(PlayerEquipment::Outer)) {
         item_id = PlayerEquipment::Outer;
-    } else if ((py.inventory[PlayerEquipment::Head].flags & config::treasure::flags::TR_CURSED) != 0u) {
+    } else if (playerWornItemIsCursed(PlayerEquipment::Head)) {
         item_id = PlayerEquipment::Head;
-    } else if ((py.inventory[PlayerEquipment::Hands].flags & config::treasure::flags::TR_CURSED) != 0u) {
+    } else if (playerWornItemIsCursed(PlayerEquipment::Hands)) {
         item_id = PlayerEquipment::Hands;
-    } else if ((py.inventory[PlayerEquipment::Feet].flags & config::treasure::flags::TR_CURSED) != 0u) {
+    } else if (playerWornItemIsCursed(PlayerEquipment::Feet)) {
         item_id = PlayerEquipment::Feet;
     }
 
@@ -107,7 +104,7 @@ static bool scrollEnchantWeaponToHit() {
     printMessage(msg);
 
     if (spellEnchantItem(item.to_hit, 10)) {
-        item.flags &= ~config::treasure::flags::TR_CURSED;
+        inventoryItemRemoveCurse(item);
         playerRecalculateBonuses();
     } else {
         printMessage("The enchantment fails.");
@@ -141,7 +138,7 @@ static bool scrollEnchantWeaponToDamage() {
     }
 
     if (spellEnchantItem(item.to_damage, scroll_type)) {
-        item.flags &= ~config::treasure::flags::TR_CURSED;
+        inventoryItemRemoveCurse(item);
         playerRecalculateBonuses();
     } else {
         printMessage("The enchantment fails.");
@@ -167,7 +164,7 @@ static bool scrollEnchantItemToAC() {
     printMessage(msg);
 
     if (spellEnchantItem(item.to_ac, 10)) {
-        item.flags &= ~config::treasure::flags::TR_CURSED;
+        inventoryItemRemoveCurse(item);
         playerRecalculateBonuses();
     } else {
         printMessage("The enchantment fails.");
@@ -195,7 +192,7 @@ static int scrollIdentifyItem(int item_id, bool &is_used_up) {
 }
 
 static bool scrollRemoveCurse() {
-    if (spellRemoveCurseFromAllItems()) {
+    if (spellRemoveCurseFromAllWornItems()) {
         printMessage("You feel as if someone is watching over you.");
         return true;
     }
@@ -271,7 +268,7 @@ static bool scrollEnchantWeapon() {
     }
 
     if (enchanted) {
-        item.flags &= ~config::treasure::flags::TR_CURSED;
+        inventoryItemRemoveCurse(item);
         playerRecalculateBonuses();
     } else {
         printMessage("The enchantment fails.");
@@ -335,7 +332,7 @@ static bool scrollEnchantArmor() {
     }
 
     if (enchanted) {
-        item.flags &= ~config::treasure::flags::TR_CURSED;
+        inventoryItemRemoveCurse(item);
         playerRecalculateBonuses();
     } else {
         printMessage("The enchantment fails.");
