@@ -1,10 +1,7 @@
 // Copyright (c) 1981-86 Robert A. Koeneke
 // Copyright (c) 1987-94 James E. Wilson
 //
-// This work is free software released under the GNU General Public License
-// version 2.0, and comes with ABSOLUTELY NO WARRANTY.
-//
-// See LICENSE and AUTHORS for more information.
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #pragma once
 
@@ -90,5 +87,5 @@ void spellLoseEXP(int32_t adjustment);
 bool spellSlowPoison();
 void spellDestroyArea(Coord_t coord);
 bool spellEnchantItem(int16_t &plusses, int16_t max_bonus_limit);
-bool spellRemoveCurseFromAllItems();
+bool spellRemoveCurseFromAllWornItems();
 bool spellRestorePlayerLevels();
