@@ -1,10 +1,7 @@
 // Copyright (c) 1981-86 Robert A. Koeneke
 // Copyright (c) 1987-94 James E. Wilson
 //
-// This work is free software released under the GNU General Public License
-// version 2.0, and comes with ABSOLUTELY NO WARRANTY.
-//
-// See LICENSE and AUTHORS for more information.
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "headers.h"
 
@@ -165,7 +162,7 @@ static bool staffDischarge(Inventory_t &item) {
                 identified = spellMassPolymorph();
                 break;
             case StaffSpellTypes::RemoveCurse:
-                if (spellRemoveCurseFromAllItems()) {
+                if (spellRemoveCurseFromAllWornItems()) {
                     if (py.flags.blind < 1) {
                         printMessage("The staff glows blue for a moment..");
                     }
