@@ -1,10 +1,7 @@
 // Copyright (c) 1981-86 Robert A. Koeneke
 // Copyright (c) 1987-94 James E. Wilson
 //
-// This work is free software released under the GNU General Public License
-// version 2.0, and comes with ABSOLUTELY NO WARRANTY.
-//
-// See LICENSE and AUTHORS for more information.
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 // Store: entering, command interpreter, buying, selling
 
@@ -210,7 +207,7 @@ static bool storeGetItemId(int &item_id, const char *prompt, int item_pos_start,
     (void) sprintf(msg, "(Items %c-%c, ESC to exit) %s", item_pos_start + 'a', item_pos_end + 'a', prompt);
 
     char key_char;
-    while (getCommand(msg, key_char)) {
+    while (getMenuItemId(msg, key_char)) {
         key_char -= 'a';
         if (key_char >= item_pos_start && key_char <= item_pos_end) {
             item_found = true;
