@@ -1,10 +1,7 @@
 // Copyright (c) 1981-86 Robert A. Koeneke
 // Copyright (c) 1987-94 James E. Wilson
 //
-// This work is free software released under the GNU General Public License
-// version 2.0, and comes with ABSOLUTELY NO WARRANTY.
-//
-// See LICENSE and AUTHORS for more information.
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #pragma once
 
@@ -76,8 +73,11 @@ void printMessage(const char *msg);
 void printMessageNoCommandInterrupt(const std::string &msg);
 char getKeyInput();
 bool getCommand(const std::string &prompt, char &command);
+bool getMenuItemId(const std::string &prompt, char &command);
+bool getTileCharacter(const std::string &prompt, char &command);
 bool getStringInput(char *in_str, Coord_t coord, int slen);
 bool getInputConfirmation(const std::string &prompt);
+int getInputConfirmationWithAbort(int column, const std::string &prompt);
 void waitForContinueKey(int line_number);
 bool checkForNonBlockingKeyPress(int microseconds);
 void getDefaultPlayerName(char *buffer);
@@ -133,8 +133,8 @@ void displaySpellsList(const int *spell_ids, int number_of_choices, bool comment
 void displayCharacterExperience();
 
 // UI Inventory/Equipment
-int displayInventory(int item_id_start, int item_id_end, bool weighted, int column, const char *mask);
+int displayInventoryItems(int itemIdStart, int itemIdEnd, bool weighted, int column, const char *mask);
 const char *playerItemWearingDescription(int body_location);
-int displayEquipment(bool weighted, int column);
+int displayEquipment(bool showWeights, int column);
 void inventoryExecuteCommand(char command);
-bool inventoryGetInputForItemId(int &command_key_id, const char *prompt, int item_id_start, int item_id_end, char *mask, const char *message);
+bool inventoryGetInputForItemId(int &commandKeyId, const char *prompt, int itemIdStart, int itemIdEnd, char *mask, const char *message);
