@@ -1,10 +1,7 @@
 // Copyright (c) 1981-86 Robert A. Koeneke
 // Copyright (c) 1987-94 James E. Wilson
 //
-// This work is free software released under the GNU General Public License
-// version 2.0, and comes with ABSOLUTELY NO WARRANTY.
-//
-// See LICENSE and AUTHORS for more information.
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 // Version history and info, and wizard mode debugging aids.
 
@@ -31,7 +28,7 @@ bool enterWizardMode() {
 }
 
 void wizardCureAll() {
-    (void) spellRemoveCurseFromAllItems();
+    (void) spellRemoveCurseFromAllWornItems();
     (void) playerCureBlindness();
     (void) playerCureConfusion();
     (void) playerCurePoison();
